#!/bin/sh
##############################################################
# glurestore.sh
#
# USAGE:
# Boot system with a rescue CD or any bootable medium
# that supports your type of disks (SATA/SCSI or IDE).
#
# Mount the medium containing the backed-up files and
# run the restore script:
# e.g. mount /dev/hda /mnt  
#      /mnt/glurestore.sh
#
# In this example the system is on /dev/sda
# and the CD/DVD ROM drive is on /dev/hda
# There are four primary partitions:
# /dev/sda1 contains HW manufacturer utilities and will not be formatted
# /dev/sda2 will be formatted using ext3 and will hold the system root (/)
# /dev/sda3 will be formatted using ext3 (but will not be used)
# /dev/sda4 will be formatted using ext3 and will hold /home
#
# 061116 jp/dm
# 080102 dm - note that a space is needed after the GRUB commands
# 120207 dm - reread partitions, remove system-specific information
##############################################################

# Change to the restore medium directory
cd /mnt

# Optionally install Master Boot Record
# (uncomment the following two lines)
#echo "Installing MBR"
#dd if=mbr.bin of=/dev/sda bs=512 count=1

# Create Partitions
# The sfdisk program used has been copied
# on the backup medium.
echo "Creating Partition Table"
./sfdisk /dev/sda < sys_partitions.txt

# Reread partitions (with a short delay)
echo "Rereading partition tables (rescan, sfdisk)"
echo 1 > /sys/block/sda/device/rescan
sleep 1
"$SFDISK" -R /dev/sda
sleep 1

# Format partitions
# Change to reflect the number of partitions that need
# to be formatted and the type of formatting
echo "Formating Partitions"
mkfs.ext3 /dev/sda2 
mkfs.ext3 /dev/sda3 
mkfs.ext3 /dev/sda4 

# Create directory to mount "/" partition
echo "Creating  directory to mount / partition "
mkdir /mnt2
mount /dev/sda2 /mnt2

# Create /proc /sys and /mnt directories
echo "Creating  proc, sys and mnt directories "
mkdir /mnt2/proc
mkdir /mnt2/sys
mkdir /mnt2/mnt

# Create directory and mount "home" partition
echo "Creating  directory and mounting home partition "
mkdir /mnt2/home
mount /dev/sda4 /mnt2/home

# Extract files
tar -C /mnt2 -xpvzf syscopy.tgz 
tar -C /mnt2 -xpvzf homecopy.tgz

#####################################
# Optional commands may be placed here
# to remove hard-coded information or 
# to add system-specific parameters
#####################################

rm -f /mnt2/etc/iftab
rm -f /mnt2/etc/udev/rules.d/70-persistent-net.rules
rm -f /mnt1/var/lib/dbus/machine-id
rm -f /mnt2/root/.bash_history
rm -f /mnt2/home/__user__/.bash_history

# Now make sure that correct boot information
# is present in the hard disk's MBR
# grub is run in batch mode
# hd0,1 is hard disk 0 (first hard disk of any kind), second partition – for this example
/sbin/grub --batch <<EOF
root (hd0,1)
setup (hd0)
quit
EOF

# Notify user
echo -e “glurestore: finished! \a”

# Reboot and check your new system
reboot
